@@ -15,8 +15,8 @@ PROJECT_ROOT = TESTS_ROOT.parent
 RESOURCE_ROOT = PROJECT_ROOT / "resources"
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 @pytest.mark.parametrize(
     ("url", "name", "strict"),
     [
@@ -52,7 +52,7 @@ def test_text_extraction_slow(caplog, url: str, name: str, strict: bool):
     assert caplog.text == ""
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name", "strict"),
     [
@@ -89,7 +89,7 @@ def test_text_extraction_fast(caplog, url: str, name: str, strict: bool):
     assert caplog.text == ""
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_parse_encoding_advanced_encoding_not_implemented(caplog):
     reader = PdfReader(BytesIO(get_data_from_url(name="tika-957144.pdf")))
     for page in reader.pages:
@@ -97,14 +97,14 @@ def test_parse_encoding_advanced_encoding_not_implemented(caplog):
     assert "Advanced encoding /WinAnsEncoding not implemented yet" in caplog.text
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_ascii_charset():
     # Issue #1312
     reader = PdfReader(BytesIO(get_data_from_url(name="ascii charset.pdf")))
     assert "/a" not in reader.pages[0].extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name", "page_nb", "within_text"),
     [
@@ -130,14 +130,14 @@ def test_text_extraction_of_specific_pages(
     assert within_text in reader.pages[page_nb].extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss1533():
     reader = PdfReader(BytesIO(get_data_from_url(name="iss1533.pdf")))
     reader.pages[0].extract_text()  # no error
     assert build_char_map("/F", 200, reader.pages[0])[3]["\x01"] == "Ü"
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name", "page_index", "within_text", "caplog_text"),
     [
@@ -165,7 +165,7 @@ def test_cmap_encodings(caplog, url, name, page_index, within_text, caplog_text)
     assert caplog_text in caplog.text
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_latex():
     reader = PdfReader(BytesIO(get_data_from_url(name="math_latex.pdf")))
     txt = reader.pages[0].extract_text()  # no error
@@ -174,7 +174,7 @@ def test_latex():
     # actually the ϕ and φ seems to be crossed in latex
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_unixxx_glyphs():
     reader = PdfReader(BytesIO(get_data_from_url(name="unixxx_glyphs.pdf")))
     txt = reader.pages[0].extract_text()  # no error
@@ -182,7 +182,7 @@ def test_unixxx_glyphs():
         assert pat in txt
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_cmap_compute_space_width():
     # issue 2137
     # original file URL:
@@ -193,21 +193,21 @@ def test_cmap_compute_space_width():
     reader.pages[0].extract_text()  # no error
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_tabs_in_cmap():
     """Issue #2173"""
     reader = PdfReader(BytesIO(get_data_from_url(name="iss2173.pdf")))
     reader.pages[0].extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_ignoring_non_put_entries():
     """Issue #2290"""
     reader = PdfReader(BytesIO(get_data_from_url(name="iss2290.pdf")))
     reader.pages[0].extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_eten_b5():
     """Issue #2356"""
     reader = PdfReader(BytesIO(get_data_from_url(name="iss2290.pdf")))
@@ -239,7 +239,7 @@ def test_null_missing_width():
     page.extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_unigb_utf16():
     """Cf #2812"""
     url = (
@@ -250,7 +250,7 @@ def test_unigb_utf16():
     assert "《中国能源展望 2060（2024 年版）》编写委员会" in reader.pages[1].extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_too_many_differences():
     """Cf #2836"""
     url = (
