@@ -74,21 +74,21 @@ def image_similarity(
     return 1 - mse
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_image_similarity_one():
     path_a = SAMPLE_ROOT / "018-base64-image/page-0-QuickPDFImd32aa1ab.png"
     path_b = path_a
     assert image_similarity(path_a, path_b) == 1
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_image_similarity_zero():
     path_a = SAMPLE_ROOT / "018-base64-image/page-0-QuickPDFImd32aa1ab.png"
     path_b = SAMPLE_ROOT / "009-pdflatex-geotopo/page-23-Im2.png"
     assert image_similarity(path_a, path_b) == 0
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_image_similarity_mid():
     path_a = SAMPLE_ROOT / "018-base64-image/page-0-QuickPDFImd32aa1ab.png"
     img_b = Image.open(path_a)
@@ -107,7 +107,7 @@ def test_image_similarity_mid():
     assert sim2 > 0
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_image_new_property():
     name = "pdf_font_garbled.pdf"
     reader = PdfReader(BytesIO(get_data_from_url(name=name)))
@@ -203,7 +203,7 @@ def test_image_new_property():
         "019-grayscale-image/page-0-X0.png",
     ],
 )
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_image_extraction(src, page_index, image_key, expected):
     reader = PdfReader(src)
     actual_image = reader.pages[page_index].images[image_key]
@@ -214,7 +214,7 @@ def test_image_extraction(src, page_index, image_key, expected):
     assert image_similarity(BytesIO(actual_image.data), expected) >= 0.99
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.timeout(30)
 def test_loop_in_image_keys():
     """Cf #2077"""
@@ -223,7 +223,7 @@ def test_loop_in_image_keys():
     reader.pages[0].images.keys()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_devicen_cmyk_black_only():
     """Cf #2321"""
     url = "https://github.com/py-pdf/pypdf/files/13501846/Addressing_Adversarial_Attacks.pdf"
@@ -239,7 +239,7 @@ def test_devicen_cmyk_black_only():
     assert image_similarity(reader.pages[10].images[0].image, img) >= 0.99
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_bi_in_text():
     """Cf #2456"""
     url = "https://github.com/py-pdf/pypdf/files/14322910/BI_text_with_one_image.pdf"
@@ -249,7 +249,7 @@ def test_bi_in_text():
     assert reader.pages[0].images[0].name == "~0~.png"
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_cmyk_no_filter():
     """Cf #2522"""
     url = "https://github.com/py-pdf/pypdf/files/14614887/out3.pdf"
@@ -258,7 +258,7 @@ def test_cmyk_no_filter():
     reader.pages[0].images[0].image
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_separation_1byte_to_rgb_inverted():
     """Cf #2343"""
     url = "https://github.com/py-pdf/pypdf/files/13679585/test2_P038-038.pdf"
@@ -274,7 +274,7 @@ def test_separation_1byte_to_rgb_inverted():
         reader.pages[0].images[0]
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_data_with_lf():
     """Cf #2343"""
     url = "https://github.com/py-pdf/pypdf/files/13946477/panda.pdf"
@@ -286,7 +286,7 @@ def test_data_with_lf():
     assert image_similarity(reader.pages[8].images[9].image, img) == 1.0
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_oserror():
     """Cf #2265"""
     url = "https://github.com/py-pdf/pypdf/files/13127130/Binance.discovery.responses.2.gov.uscourts.dcd.256060.140.1.pdf"
@@ -316,7 +316,7 @@ def test_oserror():
         ),
     ],
 )
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_corrupted_jpeg_iss2266(pdf, pdf_name, images, images_name, filtr):
     """
     Code to create zipfile:
@@ -348,7 +348,7 @@ def test_corrupted_jpeg_iss2266(pdf, pdf_name, images, images_name, filtr):
             assert image_similarity(reader.pages[p].images[i].image, img) >= 0.99
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.timeout(30)
 def test_large_compressed_image():
     url = "https://github.com/py-pdf/pypdf/files/15306199/file_with_large_compressed_image.pdf"
@@ -358,7 +358,7 @@ def test_large_compressed_image():
     list(reader.pages[0].images)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_ff_fe_starting_lut():
     """Cf issue #2660"""
     url = "https://github.com/py-pdf/pypdf/files/15385628/original_before_merge.pdf"
@@ -374,7 +374,7 @@ def test_ff_fe_starting_lut():
     assert image_similarity(reader.pages[1].images[0].image, img) == 1.0
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_inline_image_extraction():
     """Cf #2598"""
     url = "https://github.com/py-pdf/pypdf/files/14982414/lebo102.pdf"
@@ -443,7 +443,7 @@ def test_inline_image_extraction():
     assert image_similarity(reader.pages[0].images[0].image, img) == 1
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_extract_image_from_object(caplog):
     url = "https://github.com/py-pdf/pypdf/files/15176076/B2.pdf"
     name = "iss2613.pdf"
@@ -464,7 +464,7 @@ def test_extract_image_from_object(caplog):
     assert "does not seem to be an Image" in caplog.text
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_4bits_images(caplog):
     url = "https://github.com/user-attachments/files/16624406/tt.pdf"
     name = "iss2411.pdf"
