@@ -224,7 +224,7 @@ def test_merge_write_closed_fh_with_writer(pdf_file_path):
     merger.add_outline_item("An outline item", 0)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_trim_outline_list_with_writer(pdf_file_path):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/995/995175.pdf"
     name = "tika-995175.pdf"
@@ -236,7 +236,7 @@ def test_trim_outline_list_with_writer(pdf_file_path):
     merger.close()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_zoom_with_writer(pdf_file_path):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/994/994759.pdf"
     name = "tika-994759.pdf"
@@ -247,7 +247,7 @@ def test_zoom_with_writer(pdf_file_path):
     merger.close()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.filterwarnings("ignore::DeprecationWarning")
 def test_zoom_xyz_no_left_with_add_page(pdf_file_path):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/933/933322.pdf"
@@ -260,7 +260,7 @@ def test_zoom_xyz_no_left_with_add_page(pdf_file_path):
     merger.close()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_zoom_xyz_no_left_with_writer(pdf_file_path):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/933/933322.pdf"
     name = "tika-933322.pdf"
@@ -271,8 +271,8 @@ def test_zoom_xyz_no_left_with_writer(pdf_file_path):
     merger.close()
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 def test_outline_item_with_writer(pdf_file_path):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/997/997511.pdf"
     name = "tika-997511.pdf"
@@ -283,8 +283,8 @@ def test_outline_item_with_writer(pdf_file_path):
     merger.close()
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 def test_trim_outline_with_writer(pdf_file_path):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/982/982336.pdf"
     name = "tika-982336.pdf"
@@ -295,8 +295,8 @@ def test_trim_outline_with_writer(pdf_file_path):
     merger.close()
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 def test1_with_writer(pdf_file_path):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/923/923621.pdf"
     name = "tika-923621.pdf"
@@ -307,8 +307,8 @@ def test1_with_writer(pdf_file_path):
     merger.close()
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 def test_sweep_recursion1_with_writer(pdf_file_path):
     # TODO: This test looks like an infinite loop.
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924546.pdf"
@@ -323,8 +323,8 @@ def test_sweep_recursion1_with_writer(pdf_file_path):
     reader2.pages
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -350,7 +350,7 @@ def test_sweep_recursion2_with_writer(url, name, pdf_file_path):
     reader2.pages
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_sweep_indirect_list_newobj_is_none_with_writer(caplog, pdf_file_path):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/906/906769.pdf"
     name = "tika-906769.pdf"
@@ -365,7 +365,7 @@ def test_sweep_indirect_list_newobj_is_none_with_writer(caplog, pdf_file_path):
     reader2.pages
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss1145_with_writer():
     # issue with FitH destination with null param
     url = "https://github.com/py-pdf/pypdf/files/9164743/file-0.pdf"
@@ -375,7 +375,7 @@ def test_iss1145_with_writer():
     merger.close()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss1344_with_writer(caplog):
     url = "https://github.com/py-pdf/pypdf/files/9549001/input.pdf"
     name = "iss1344.pdf"
@@ -388,7 +388,7 @@ def test_iss1344_with_writer(caplog):
     assert "adresse où le malade peut être visité" in p.extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_articles_with_writer(caplog):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf"
     name = "924666.pdf"
