@@ -46,7 +46,7 @@ def get_all_sample_files():
 all_files_meta = get_all_sample_files()
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 @pytest.mark.parametrize(
     "meta",
     [m for m in all_files_meta["data"] if not m["encrypted"]],
@@ -63,8 +63,8 @@ def test_read(meta):
     assert len(reader.pages) == meta["pages"]
 
 
-@pytest.mark.samples()
-@pytest.mark.enable_socket()
+@pytest.mark.samples
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("pdf_path", "password"),
     [
@@ -253,7 +253,7 @@ def compare_dict_objects(d1, d2):
             assert d1[key] == d2[key]
 
 
-@pytest.mark.slow()
+@pytest.mark.slow
 def test_page_transformations():
     pdf_path = RESOURCE_ROOT / "crazyones.pdf"
     reader = PdfReader(pdf_path)
@@ -375,7 +375,7 @@ def test_add_transformation_on_page_without_contents():
     assert isinstance(page.get_contents(), ContentStream)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss_1142():
     # check fix for problem of context save/restore (q/Q)
     url = "https://github.com/py-pdf/pypdf/files/9150656/ST.2019.PDF"
@@ -393,8 +393,8 @@ def test_iss_1142():
     assert txt.find("郑州分公司") > 0
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -439,8 +439,8 @@ def test_extract_text(url, name):
         page.extract_text()
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 def test_extract_text_page_pdf_impossible_decode_xform(caplog):
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/972/972962.pdf"
     name = "tika-972962.pdf"
@@ -451,8 +451,8 @@ def test_extract_text_page_pdf_impossible_decode_xform(caplog):
     assert warn_msgs == [""]  # text extraction recognise no text
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 def test_extract_text_operator_t_star():  # L1266, L1267
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/967/967943.pdf"
     name = "tika-967943.pdf"
@@ -801,7 +801,7 @@ def test_get_fonts(pdf_path, password, embedded, unembedded):
     assert (a, b) == (embedded, unembedded)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_get_fonts2():
     url = "https://github.com/py-pdf/pypdf/files/12618104/WS_T.483.8-2016.pdf"
     name = "WS_T.483.8-2016.pdf"
@@ -940,7 +940,7 @@ def test_annotation_setter(pdf_file_path):
         writer.write(fp)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.xfail(reason="#1091")
 def test_text_extraction_issue_1091():
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/966/966635.pdf"
@@ -952,7 +952,7 @@ def test_text_extraction_issue_1091():
         page.extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_empyt_password_1088():
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/941/941536.pdf"
     name = "tika-941536.pdf"
@@ -961,7 +961,7 @@ def test_empyt_password_1088():
     len(reader.pages)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_old_habibi():
     # this habibi has multiple characters associated with the h
     reader = PdfReader(SAMPLE_ROOT / "015-arabic/habibi.pdf")
@@ -971,7 +971,7 @@ def test_old_habibi():
     assert "حَبيبي" in txt
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_read_link_annotation():
     reader = PdfReader(SAMPLE_ROOT / "016-libre-office-link/libre-office-link.pdf")
     assert len(reader.pages[0].annotations) == 1
@@ -1001,7 +1001,7 @@ def test_read_link_annotation():
     assert annot == expected
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_no_resources():
     url = "https://github.com/py-pdf/pypdf/files/9572045/108.pdf"
     name = "108.pdf"
@@ -1174,7 +1174,7 @@ def test_merge_page_resources_smoke_test():
     assert relevant_operations == expected_operations
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_merge_transformed_page_into_blank():
     url = "https://github.com/py-pdf/pypdf/files/10768334/badges_3vjrh_7LXDZ_1-1.pdf"
     name = "badges_3vjrh_7LXDZ_1.pdf"
@@ -1221,7 +1221,7 @@ def test_pages_printing():
         reader.pages[0].images["~1~"]
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_del_pages():
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/941/941536.pdf"
     name = "tika-941536.pdf"
@@ -1280,7 +1280,7 @@ def test_pdf_pages_missing_type():
     writer.pages[0]
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_merge_with_stream_wrapped_in_save_restore():
     """Test for issue #2587"""
     url = "https://github.com/py-pdf/pypdf/files/14895914/blank_portrait.pdf"
@@ -1293,7 +1293,7 @@ def test_merge_with_stream_wrapped_in_save_restore():
     assert b"QQ" not in page_one.get_contents().get_data()
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_compression():
     """Test for issue #1897"""
 
@@ -1352,7 +1352,7 @@ def test_get_contents_from_nullobject():
     page1.merge_page(page2, over=True)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_pos_text_in_textvisitor():
     """See #2200"""
     url = "https://github.com/py-pdf/pypdf/files/12675974/page_178.pdf"
@@ -1370,7 +1370,7 @@ def test_pos_text_in_textvisitor():
     assert abs(p[1] - 457.4) < 0.1
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_pos_text_in_textvisitor2():
     """See #2075"""
     url = "https://github.com/py-pdf/pypdf/files/12318042/LegIndex-page6.pdf"
@@ -1430,7 +1430,7 @@ def test_pos_text_in_textvisitor2():
     ]
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_missing_basefont_in_type3():
     """Cf #2289"""
     url = "https://github.com/py-pdf/pypdf/files/13307713/missing-base-font.pdf"
