@@ -191,8 +191,8 @@ def test_rotate_45():
         assert exc.value.args[0] == "Rotation angle must be a multiple of 90"
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 @pytest.mark.parametrize(
     ("enable", "url", "pages"),
     [
@@ -273,7 +273,7 @@ def test_extract_textbench(enable, url, pages, print_result=False):
         pass
 
 
-@pytest.mark.slow()
+@pytest.mark.slow
 def test_orientations():
     p = PdfReader(RESOURCE_ROOT / "test Orient.pdf").pages[0]
     p.extract_text("", "")
@@ -308,8 +308,8 @@ def test_orientations():
         ), f"extract_text({req}) => {rst}"
 
 
-@pytest.mark.samples()
-@pytest.mark.enable_socket()
+@pytest.mark.samples
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("base_path", "overlay_path"),
     [
@@ -341,8 +341,8 @@ def test_overlay(pdf_file_path, base_path, overlay_path):
         writer.write(fp)
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -362,7 +362,7 @@ def test_merge_with_warning(tmp_path, url, name):
     merger.write(tmp_path / "tmp.merged.pdf")
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -381,7 +381,7 @@ def test_merge(tmp_path, url, name):
     merger.write(tmp_path / "tmp.merged.pdf")
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name", "expected_metadata"),
     [
@@ -407,7 +407,7 @@ def test_get_metadata(url, name, expected_metadata):
     assert expected_metadata == data
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name", "strict", "exception"),
     [
@@ -493,7 +493,7 @@ def test_extract_text(url, name, strict, exception):
         assert ex_info.value.args[0] == exc_text
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -529,7 +529,7 @@ def test_compress_raised(url, name):
         page.compress_content_streams()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -554,7 +554,7 @@ def test_get_fields_warns(tmp_path, caplog, url, name):
     ]
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -574,7 +574,7 @@ def test_get_fields_no_warning(tmp_path, url, name):
     assert len(retrieved_fields) == 10
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_scale_rectangle_indirect_object():
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/999/999944.pdf"
     name = "tika-999944.pdf"
@@ -613,7 +613,7 @@ def test_merge_output(caplog):
     merger.close()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -685,7 +685,7 @@ def test_image_extraction(url, name):
                 Path(filepath).unlink()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_image_extraction_strict():
     # Emits log messages
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/914/914102.pdf"
@@ -713,7 +713,7 @@ def test_image_extraction_strict():
                 Path(filepath).unlink()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -747,7 +747,7 @@ def test_image_extraction2(url, name):
                 Path(filepath).unlink()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -767,7 +767,7 @@ def test_get_outline(url, name):
     reader.outline
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -787,7 +787,7 @@ def test_get_xfa(url, name):
     reader.xfa
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name", "strict"),
     [
@@ -820,7 +820,7 @@ def test_get_fonts(url, name, strict):
         page._get_fonts()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("url", "name", "strict"),
     [
@@ -878,7 +878,7 @@ def test_get_xmp(url, name, strict):
         xmp_info.custom_properties
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_tounicode_is_identity():
     url = "https://github.com/py-pdf/pypdf/files/9998335/FP_Thesis.pdf"
     name = "FP_Thesis.pdf"
@@ -887,7 +887,7 @@ def test_tounicode_is_identity():
     reader.pages[0].extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_append_forms():
     # from #1538
     writer = PdfWriter()
@@ -912,7 +912,7 @@ def test_append_forms():
     ) + len(reader2.get_form_text_fields())
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_extra_test_iss1541():
     url = "https://github.com/py-pdf/pypdf/files/10418158/tst_iss1541.pdf"
     name = "tst_iss1541.pdf"
@@ -943,7 +943,7 @@ def test_extra_test_iss1541():
     assert exc.value.args[0] == "Unexpected end of stream"
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_fields_returning_stream():
     """This problem was reported in #424"""
     url = "https://github.com/mstamy2/PyPDF2/files/1948267/Simple.form.pdf"
@@ -997,7 +997,7 @@ def test_replace_image(tmp_path):
         pypdf._page.pil_not_imported = False
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_inline_images():
     """This problem was reported in #424"""
     url = "https://arxiv.org/pdf/2201.00151.pdf"
@@ -1025,7 +1025,7 @@ def test_inline_images():
 
     _a = {}
     for x, y in reader.pages[2].images[0:-2].items():
-        _a[x] = y
+        _a[x] = y  # noqa: PERF403  # Testing code and easier to read this way.
     with pytest.raises(KeyError) as exc:
         reader.pages[2]._get_image(("test",))
 
@@ -1035,7 +1035,7 @@ def test_inline_images():
     assert len(reader.pages[0].images) == 3
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss():
     url = "https://github.com/py-pdf/pypdf/files/11801077/lv2018tconv.pdf"
     name = "lv2018tconv.pdf"
@@ -1045,7 +1045,7 @@ def test_iss():
         page.extract_text()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_cr_with_cm_operation():
     """Issue #2138"""
     url = "https://github.com/py-pdf/pypdf/files/12483807/AEO.1172.pdf"
@@ -1068,7 +1068,7 @@ def remove_trailing_whitespace(text: str) -> str:
     return "\n".join(line.rstrip() for line in text.splitlines())
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 @pytest.mark.parametrize(
     ("pdf_path", "expected_path"),
     [
@@ -1090,7 +1090,7 @@ def test_text_extraction_layout_mode(pdf_path, expected_path):
     assert remove_trailing_whitespace(actual) == remove_trailing_whitespace(expected)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_layout_mode_space_vertically():
     reader = PdfReader(BytesIO(get_data_from_url(name="iss2138.pdf")))
     # remove automatically added final newline
@@ -1102,7 +1102,7 @@ def test_layout_mode_space_vertically():
     )
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.parametrize(
     ("rotation", "strip_rotated"), [(90, True), (180, False), (270, True)]
 )
@@ -1131,7 +1131,7 @@ def test_text_extraction_invalid_mode():
         reader.pages[0].extract_text(extraction_mode="foo")  # type: ignore
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_get_page_showing_field():
     """
     Uses testfile from #2452 in order to get fields on multiple pages,
@@ -1197,7 +1197,7 @@ def test_get_page_showing_field():
         reader.get_pages_showing_field(None)
     with pytest.raises(ValueError) as exc:
         writer.get_pages_showing_field(None)
-    assert "field type is invalid" in exc.value.args[0]
+    assert "Field type is invalid" in exc.value.args[0]
 
     # Damage Field
     del reader.trailer["/Root"]["/AcroForm"]["/Fields"][1].get_object()["/FT"]
@@ -1208,7 +1208,7 @@ def test_get_page_showing_field():
         )
     with pytest.raises(ValueError) as exc:
         writer.get_pages_showing_field(writer._root_object["/AcroForm"]["/Fields"][1])
-    assert "field is not valid" in exc.value.args[0]
+    assert "Field is not valid" in exc.value.args[0]
 
     # missing Parent in field
     del reader.trailer["/Root"]["/AcroForm"]["/Fields"][99]["/Kids"][1].get_object()[
@@ -1288,7 +1288,7 @@ def test_get_page_showing_field():
     ] == []
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_extract_empty_page():
     """Cf #2533"""
     url = "https://github.com/py-pdf/pypdf/files/14718318/test.pdf"
@@ -1297,7 +1297,7 @@ def test_extract_empty_page():
     assert reader.pages[1].extract_text(extraction_mode="layout") == ""
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss2815():
     """Cf #2815"""
     url = "https://github.com/user-attachments/files/16760725/crash-c1920c7a064649e1191d7879952ec252473fc7e6.pdf"
