@@ -126,6 +126,7 @@ def writer_operate(writer: PdfWriter) -> None:
 
     Args:
         writer: A PdfWriter object
+
     """
     pdf_path = RESOURCE_ROOT / "crazyones.pdf"
     pdf_outline_path = RESOURCE_ROOT / "pdflatex-outline.pdf"
@@ -344,7 +345,7 @@ def test_remove_images(pdf_file_path, input_path):
             assert "Lorem ipsum dolor sit amet" in extracted_text
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_remove_images_sub_level():
     """Cf #2035"""
     url = "https://github.com/py-pdf/pypdf/files/12394781/2210.03142-1.pdf"
@@ -831,8 +832,8 @@ def test_append_pages_from_reader_append():
         writer.write(b)
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 @pytest.mark.filterwarnings("ignore::DeprecationWarning")
 def test_sweep_indirect_references_nullobject_exception(pdf_file_path):
     # TODO: Check this more closely... this looks weird
@@ -844,8 +845,8 @@ def test_sweep_indirect_references_nullobject_exception(pdf_file_path):
     merger.write(pdf_file_path)
 
 
-@pytest.mark.enable_socket()
-@pytest.mark.slow()
+@pytest.mark.enable_socket
+@pytest.mark.slow
 @pytest.mark.parametrize(
     ("url", "name"),
     [
@@ -953,7 +954,7 @@ def test_add_single_annotation(pdf_file_path):
         writer.write(fp)
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_colors_in_outline_item(pdf_file_path):
     reader = PdfReader(SAMPLE_ROOT / "004-pdflatex-4-pages/pdflatex-4-pages.pdf")
     writer = PdfWriter()
@@ -974,7 +975,7 @@ def test_colors_in_outline_item(pdf_file_path):
         ]
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_write_empty_stream():
     reader = PdfReader(SAMPLE_ROOT / "004-pdflatex-4-pages/pdflatex-4-pages.pdf")
     writer = PdfWriter()
@@ -982,7 +983,7 @@ def test_write_empty_stream():
 
     with pytest.raises(ValueError) as exc:
         writer.write("")
-    assert exc.value.args[0] == "Output(stream=) is empty."
+    assert exc.value.args[0] == "Output(stream='') is empty."
 
 
 def test_startup_dest():
@@ -1026,7 +1027,7 @@ def test_startup_dest():
     pdf_file_writer.open_destination = None
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss471():
     url = "https://github.com/py-pdf/pypdf/files/9139245/book.pdf"
     name = "book_471.pdf"
@@ -1039,7 +1040,7 @@ def test_iss471():
     )
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_reset_translation():
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf"
     name = "tika-924666.pdf"
@@ -1077,7 +1078,7 @@ def test_threads_empty():
     assert thr == thr2
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_append_without_annots_and_articles():
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf"
     name = "tika-924666.pdf"
@@ -1096,7 +1097,7 @@ def test_append_without_annots_and_articles():
     assert len(writer.threads) >= 1
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_append_multiple():
     url = "https://corpora.tika.apache.org/base/docs/govdocs1/924/924666.pdf"
     name = "tika-924666.pdf"
@@ -1111,7 +1112,7 @@ def test_append_multiple():
     assert pages[-1] not in pages[0:-1]  # page not repeated
 
 
-@pytest.mark.samples()
+@pytest.mark.samples
 def test_set_page_label(pdf_file_path):
     src = RESOURCE_ROOT / "GeoBase_NHNC1_Data_Model_UML_EN.pdf"  # File without labels
     reader = PdfReader(src)
@@ -1187,21 +1188,21 @@ def test_set_page_label(pdf_file_path):
     writer = PdfWriter()
     writer.clone_document_from_reader(reader)
     with pytest.raises(
-        ValueError, match="at least one between style and prefix must be given"
+        ValueError, match="At least one of style and prefix must be given"
     ):
         writer.set_page_label(0, 5, start=2)
     with pytest.raises(
-        ValueError, match="page_index_from must be equal or greater then 0"
+        ValueError, match="page_index_from must be greater or equal than 0"
     ):
         writer.set_page_label(-1, 5, "/r")
     with pytest.raises(
-        ValueError, match="page_index_to must be equal or greater then page_index_from"
+        ValueError, match="page_index_to must be greater or equal than page_index_from"
     ):
         writer.set_page_label(5, 0, "/r")
     with pytest.raises(ValueError, match="page_index_to exceeds number of pages"):
         writer.set_page_label(0, 19, "/r")
     with pytest.raises(
-        ValueError, match="if given, start must be equal or greater than one"
+        ValueError, match="If given, start must be greater or equal than one"
     ):
         writer.set_page_label(0, 5, "/r", start=-1)
 
@@ -1246,7 +1247,7 @@ def test_set_page_label(pdf_file_path):
     writer.write(pdf_file_path)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss1601():
     url = "https://github.com/py-pdf/pypdf/files/10579503/badges-38.pdf"
     name = "badge-38.pdf"
@@ -1315,7 +1316,7 @@ def test_attachments():
     assert reader.attachments["foobar2.txt"][1] == b"2nd_foobarcontent"
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss1614():
     # test of an annotation(link) directly stored in the /Annots in the page
     url = "https://github.com/py-pdf/pypdf/files/10669995/broke.pdf"
@@ -1330,7 +1331,7 @@ def test_iss1614():
     writer.append(reader)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_new_removes():
     # test of an annotation(link) directly stored in the /Annots in the page
     url = "https://github.com/py-pdf/pypdf/files/10807951/tt.pdf"
@@ -1384,7 +1385,7 @@ def test_new_removes():
     writer.remove_annotations("/Text")
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_late_iss1654():
     url = "https://github.com/py-pdf/pypdf/files/10935632/bid1.pdf"
     name = "bid1.pdf"
@@ -1397,7 +1398,7 @@ def test_late_iss1654():
     writer.write(b)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss1723():
     # test of an annotation(link) directly stored in the /Annots in the page
     url = "https://github.com/py-pdf/pypdf/files/11015242/inputFile.pdf"
@@ -1407,7 +1408,7 @@ def test_iss1723():
     writer.append(reader, (3, 5))
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss1767():
     # test with a pdf which is buggy because the object 389,0 exists 3 times:
     # twice to define catalog and one as an XObject inducing a loop when
@@ -1418,7 +1419,7 @@ def test_iss1767():
     PdfWriter(clone_from=reader)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_named_dest_page_number():
     """
     Closes iss471
@@ -1515,7 +1516,7 @@ def test_update_form_fields(tmp_path):
     Path(write_data_here).unlink()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_update_form_fields2():
     myFiles = {
         "test1": {
@@ -1596,7 +1597,7 @@ def test_update_form_fields2():
     }
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_iss1862():
     # The file here has "/B" entry to define the font in a object below the page
     # The excluded field shall be considered only at first level (page) and not
@@ -1623,7 +1624,7 @@ def test_empty_objects_before_cloning():
     assert len(writer._objects) == nb_obj_reader
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_watermark():
     url = "https://github.com/py-pdf/pypdf/files/11985889/bg.pdf"
     name = "bgwatermark.pdf"
@@ -1642,7 +1643,7 @@ def test_watermark():
     assert len(b.getvalue()) < 2.1 * 1024 * 1024
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.timeout(4)
 def test_watermarking_speed():
     url = "https://github.com/py-pdf/pypdf/files/11985889/bg.pdf"
@@ -1659,7 +1660,7 @@ def test_watermarking_speed():
     assert pdf_size_in_mib < 20
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 @pytest.mark.skipif(GHOSTSCRIPT_BINARY is None, reason="Requires Ghostscript")
 def test_watermark_rendering(tmp_path):
     """Ensure the visual appearance of watermarking stays correct."""
@@ -1683,8 +1684,8 @@ def test_watermark_rendering(tmp_path):
     writer.write(pdf_path)
 
     # False positive: https://github.com/PyCQA/bandit/issues/333
-    subprocess.run(
-        [  # noqa: S603
+    subprocess.run(  # noqa: S603
+        [
             GHOSTSCRIPT_BINARY,
             "-sDEVICE=pngalpha",
             "-o",
@@ -1720,8 +1721,8 @@ def test_watermarking_reportlab_rendering(tmp_path):
 
     writer.write(pdf_path)
     # False positive: https://github.com/PyCQA/bandit/issues/333
-    subprocess.run(
-        [  # noqa: S603
+    subprocess.run(  # noqa: S603
+        [
             GHOSTSCRIPT_BINARY,
             "-r120",
             "-sDEVICE=pngalpha",
@@ -1734,7 +1735,7 @@ def test_watermarking_reportlab_rendering(tmp_path):
     assert image_similarity(png_path, target_png_path) >= 0.999
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_da_missing_in_annot():
     url = "https://github.com/py-pdf/pypdf/files/12136285/Building.Division.Permit.Application.pdf"
     name = "BuildingDivisionPermitApplication.pdf"
@@ -1817,7 +1818,7 @@ def test_missing_info():
     assert b"/Info" not in b.getvalue()
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_germanfields():
     """Cf #2035"""
     url = "https://github.com/py-pdf/pypdf/files/12194195/test.pdf"
@@ -1840,7 +1841,7 @@ def test_germanfields():
     )
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_no_t_in_articles():
     """Cf #2078"""
     url = "https://github.com/py-pdf/pypdf/files/12311735/bad.pdf"
@@ -1850,7 +1851,7 @@ def test_no_t_in_articles():
     writer.append(reader)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_no_i_in_articles():
     """Cf #2089"""
     url = "https://github.com/py-pdf/pypdf/files/12352793/kim2002.pdf"
@@ -1860,7 +1861,7 @@ def test_no_i_in_articles():
     writer.append(reader)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_damaged_pdf_length_returning_none():
     """
     Cf #140
@@ -1873,7 +1874,7 @@ def test_damaged_pdf_length_returning_none():
     writer.append(reader)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_viewerpreferences():
     """Add Tests for ViewerPreferences"""
     url = "https://github.com/py-pdf/pypdf/files/9175966/2015._pb_decode_pg0.pdf"
@@ -1956,7 +1957,7 @@ def test_extra_spaces_in_da_text(caplog):
     assert b"(abcd)" in t
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_object_contains_indirect_reference_to_self():
     url = "https://github.com/py-pdf/pypdf/files/12389243/testbook.pdf"
     name = "iss2102.pdf"
@@ -1997,7 +1998,7 @@ def test_remove_image_per_type():
     assert len(writer.pages[0]["/Resources"]["/XObject"]) == 0
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_add_outlines_on_empty_dict():
     """Cf #2233"""
 
@@ -2143,7 +2144,7 @@ def test_merging_many_temporary_files(caplog):
     assert "Cannot find page in pages" in caplog.text
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_reattach_fields():
     """
     Test Reattach function
@@ -2243,7 +2244,7 @@ def test_init_without_named_arg():
     assert len(writer._objects) == nb
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_i_in_choice_fields():
     """Cf #2611"""
     url = "https://github.com/py-pdf/pypdf/files/15176321/FRA.F.6180.150.pdf"
@@ -2279,7 +2280,7 @@ def test_selfont():
     )
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_no_ressource_for_14_std_fonts(caplog):
     """Cf #2670"""
     url = "https://github.com/py-pdf/pypdf/files/15405390/f1040.pdf"
@@ -2295,7 +2296,7 @@ def test_no_ressource_for_14_std_fonts(caplog):
     assert "Font dictionary for /Helvetica not found." in caplog.text
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_field_box_upside_down():
     """Cf #2724"""
     url = "https://github.com/user-attachments/files/15996356/FRA.F.6180.55.pdf"
@@ -2312,7 +2313,7 @@ def test_field_box_upside_down():
     assert box[3] > 0
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_matrix_entry_in_field_annots():
     """Cf #2731"""
     url = "https://github.com/user-attachments/files/16036514/template.pdf"
@@ -2326,7 +2327,7 @@ def test_matrix_entry_in_field_annots():
     assert "/Matrix" in writer.pages[0]["/Annots"][5].get_object()["/AP"]["/N"]
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_compress_identical_objects():
     """Cf #2728 and #2794"""
     url = "https://github.com/user-attachments/files/16575458/tt2.pdf"
@@ -2376,7 +2377,7 @@ def test_utf16_metadata():
     )
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_increment_writer(caplog):
     """Tests for #2811"""
     writer = PdfWriter(
@@ -2470,7 +2471,7 @@ def test_increment_writer(caplog):
     writer.write(b)
 
 
-@pytest.mark.enable_socket()
+@pytest.mark.enable_socket
 def test_append_pdf_with_dest_without_page(caplog):
     """Tests for #2842"""
     url = "https://github.com/user-attachments/files/16990834/test.pdf"
